/* test-utils.c generated by valac 0.17.2.19-5f50d, the Vala compiler
 * generated from test-utils.vala, do not modify */

/*
 * Copyright (C) 2011 Collabora Ltd.
 * Copyright (C) 2012 Philip Withnall
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Travis Reitter <travis.reitter@collabora.com>
 *          Philip Withnall <philip@tecnocode.co.uk>
 *
 */

#include <glib.h>
#include <glib-object.h>
#include <gio/gio.h>
#include <stdlib.h>
#include <string.h>
#include <folks/folks.h>
#include <gobject/gvaluecollector.h>


#define FOLKS_TYPE_TEST_UTILS (folks_test_utils_get_type ())
#define FOLKS_TEST_UTILS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), FOLKS_TYPE_TEST_UTILS, FolksTestUtils))
#define FOLKS_TEST_UTILS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), FOLKS_TYPE_TEST_UTILS, FolksTestUtilsClass))
#define FOLKS_IS_TEST_UTILS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), FOLKS_TYPE_TEST_UTILS))
#define FOLKS_IS_TEST_UTILS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), FOLKS_TYPE_TEST_UTILS))
#define FOLKS_TEST_UTILS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), FOLKS_TYPE_TEST_UTILS, FolksTestUtilsClass))

typedef struct _FolksTestUtils FolksTestUtils;
typedef struct _FolksTestUtilsClass FolksTestUtilsClass;
typedef struct _FolksTestUtilsPrivate FolksTestUtilsPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _FolksTestUtilsLoadableIconsContentEqualData FolksTestUtilsLoadableIconsContentEqualData;
typedef struct _Block1Data Block1Data;
typedef struct _FolksTestUtilsAggregatorPrepareAndWaitForQuiescenceData FolksTestUtilsAggregatorPrepareAndWaitForQuiescenceData;
typedef struct _FolksParamSpecTestUtils FolksParamSpecTestUtils;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _FolksTestUtils {
	GTypeInstance parent_instance;
	volatile int ref_count;
	FolksTestUtilsPrivate * priv;
};

struct _FolksTestUtilsClass {
	GTypeClass parent_class;
	void (*finalize) (FolksTestUtils *self);
};

struct _FolksTestUtilsLoadableIconsContentEqualData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	GLoadableIcon* a;
	GLoadableIcon* b;
	gint icon_size;
	gboolean result;
	gboolean retval;
	GLoadableIcon* _tmp0_;
	GLoadableIcon* _tmp1_;
	gboolean _tmp2_;
	GLoadableIcon* _tmp3_;
	GLoadableIcon* _tmp4_;
	gboolean _tmp5_;
	gchar* a_type;
	GLoadableIcon* _tmp6_;
	gint _tmp7_;
	gchar* _tmp8_;
	GInputStream* _tmp9_;
	GInputStream* a_input;
	gchar* b_type;
	GLoadableIcon* _tmp10_;
	gint _tmp11_;
	gchar* _tmp12_;
	GInputStream* _tmp13_;
	GInputStream* b_input;
	gsize bufsize;
	gsize _tmp14_;
	guint8* _tmp15_;
	guint8* a_data;
	gint a_data_length1;
	gint _a_data_size_;
	gsize _tmp16_;
	guint8* _tmp17_;
	guint8* b_data;
	gint b_data_length1;
	gint _b_data_size_;
	gsize a_read_size;
	gboolean _tmp18_;
	gboolean _tmp19_;
	gsize _tmp20_;
	GInputStream* _tmp21_;
	guint8* _tmp22_;
	gint _tmp22__length1;
	gssize _tmp23_;
	gssize _tmp24_;
	GInputStream* _tmp25_;
	guint8* _tmp26_;
	gint _tmp26__length1;
	gssize _tmp27_;
	gssize b_read_size;
	gboolean _tmp28_;
	gsize _tmp29_;
	gssize _tmp30_;
	guint8* _tmp31_;
	gint _tmp31__length1;
	guint8* _tmp32_;
	gint _tmp32__length1;
	gsize _tmp33_;
	gint _tmp34_;
	gboolean _tmp35_;
	GInputStream* _tmp36_;
	GInputStream* _tmp37_;
	GError* e1;
	GError* _tmp38_;
	const gchar* _tmp39_;
	GError * _inner_error_;
};

struct _Block1Data {
	int _ref_count_;
	gboolean has_yielded;
	gpointer _async_data_;
};

struct _FolksTestUtilsAggregatorPrepareAndWaitForQuiescenceData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	FolksIndividualAggregator* aggregator;
	Block1Data* _data1_;
	FolksIndividualAggregator* _tmp0_;
	gulong _tmp1_;
	gulong signal_id;
	FolksIndividualAggregator* _tmp2_;
	FolksIndividualAggregator* _tmp3_;
	gboolean _tmp4_;
	gboolean _tmp5_;
	FolksIndividualAggregator* _tmp6_;
	gulong _tmp7_;
	FolksIndividualAggregator* _tmp8_;
	gboolean _tmp9_;
	gboolean _tmp10_;
	GError * _inner_error_;
};

struct _FolksParamSpecTestUtils {
	GParamSpec parent_instance;
};


static gpointer folks_test_utils_parent_class = NULL;

gpointer folks_test_utils_ref (gpointer instance);
void folks_test_utils_unref (gpointer instance);
GParamSpec* folks_param_spec_test_utils (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void folks_value_set_test_utils (GValue* value, gpointer v_object);
void folks_value_take_test_utils (GValue* value, gpointer v_object);
gpointer folks_value_get_test_utils (const GValue* value);
GType folks_test_utils_get_type (void) G_GNUC_CONST;
enum  {
	FOLKS_TEST_UTILS_DUMMY_PROPERTY
};
static void folks_test_utils_loadable_icons_content_equal_data_free (gpointer _data);
void folks_test_utils_loadable_icons_content_equal (GLoadableIcon* a, GLoadableIcon* b, gint icon_size, GAsyncReadyCallback _callback_, gpointer _user_data_);
gboolean folks_test_utils_loadable_icons_content_equal_finish (GAsyncResult* _res_);
static gboolean folks_test_utils_loadable_icons_content_equal_co (FolksTestUtilsLoadableIconsContentEqualData* _data_);
static void folks_test_utils_loadable_icons_content_equal_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void folks_test_utils_aggregator_prepare_and_wait_for_quiescence_data_free (gpointer _data);
void folks_test_utils_aggregator_prepare_and_wait_for_quiescence (FolksIndividualAggregator* aggregator, GAsyncReadyCallback _callback_, gpointer _user_data_);
void folks_test_utils_aggregator_prepare_and_wait_for_quiescence_finish (GAsyncResult* _res_, GError** error);
static gboolean folks_test_utils_aggregator_prepare_and_wait_for_quiescence_co (FolksTestUtilsAggregatorPrepareAndWaitForQuiescenceData* _data_);
static Block1Data* block1_data_ref (Block1Data* _data1_);
static void block1_data_unref (void * _userdata_);
static void __lambda2_ (Block1Data* _data1_, GObject* obj, GParamSpec* pspec);
static void ___lambda2__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void folks_test_utils_aggregator_prepare_and_wait_for_quiescence_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
FolksTestUtils* folks_test_utils_new (void);
FolksTestUtils* folks_test_utils_construct (GType object_type);
static void folks_test_utils_finalize (FolksTestUtils* obj);


static void folks_test_utils_loadable_icons_content_equal_data_free (gpointer _data) {
	FolksTestUtilsLoadableIconsContentEqualData* _data_;
	_data_ = _data;
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	_g_object_unref0 (_data_->a);
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	_g_object_unref0 (_data_->b);
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	g_slice_free (FolksTestUtilsLoadableIconsContentEqualData, _data_);
#line 210 "test-utils.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	return self ? g_object_ref (self) : NULL;
#line 217 "test-utils.c"
}


void folks_test_utils_loadable_icons_content_equal (GLoadableIcon* a, GLoadableIcon* b, gint icon_size, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	FolksTestUtilsLoadableIconsContentEqualData* _data_;
	GLoadableIcon* _tmp0_;
	GLoadableIcon* _tmp1_;
	GLoadableIcon* _tmp2_;
	GLoadableIcon* _tmp3_;
	gint _tmp4_;
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	_data_ = g_slice_new0 (FolksTestUtilsLoadableIconsContentEqualData);
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	_data_->_async_result = g_simple_async_result_new (NULL, _callback_, _user_data_, folks_test_utils_loadable_icons_content_equal);
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, folks_test_utils_loadable_icons_content_equal_data_free);
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	_tmp0_ = a;
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	_data_->a = _tmp1_;
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	_tmp2_ = b;
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	_data_->b = _tmp3_;
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	_tmp4_ = icon_size;
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	_data_->icon_size = _tmp4_;
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	folks_test_utils_loadable_icons_content_equal_co (_data_);
#line 252 "test-utils.c"
}


gboolean folks_test_utils_loadable_icons_content_equal_finish (GAsyncResult* _res_) {
	gboolean result;
	FolksTestUtilsLoadableIconsContentEqualData* _data_;
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	result = _data_->result;
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	return result;
#line 265 "test-utils.c"
}


/**
   * Compare the content of two {@link LoadableIcon}s for equality.
   *
   * This is in contrast to {@link Icon.equal}, which returns `false` for
   * identical icons stored in different subclasses or in different storage
   * locations.
   *
   * This function is particularly useful for tests which compare an avatar set
   * on an {@link AvatarDetails}'s with that object's final avatar, since it may
   * be stored in a location in the avatar cache.
   *
   * @param a the first icon
   * @param b the second icon
   * @param size the size at which to compare the icons
   * @return `true` if the instances are equal, `false` otherwise
   */
static void folks_test_utils_loadable_icons_content_equal_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	FolksTestUtilsLoadableIconsContentEqualData* _data_;
#line 58 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	_data_ = _user_data_;
#line 58 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	_data_->_source_object_ = source_object;
#line 58 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	_data_->_res_ = _res_;
#line 58 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	folks_test_utils_loadable_icons_content_equal_co (_data_);
#line 295 "test-utils.c"
}


static gboolean folks_test_utils_loadable_icons_content_equal_co (FolksTestUtilsLoadableIconsContentEqualData* _data_) {
#line 44 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	switch (_data_->_state_) {
#line 44 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		case 0:
#line 304 "test-utils.c"
		goto _state_0;
#line 44 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		case 1:
#line 308 "test-utils.c"
		goto _state_1;
#line 44 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		case 2:
#line 312 "test-utils.c"
		goto _state_2;
#line 44 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		case 3:
#line 316 "test-utils.c"
		goto _state_3;
#line 44 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		case 4:
#line 320 "test-utils.c"
		goto _state_4;
#line 44 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		case 5:
#line 324 "test-utils.c"
		goto _state_5;
#line 44 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		case 6:
#line 328 "test-utils.c"
		goto _state_6;
		default:
#line 44 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		g_assert_not_reached ();
#line 333 "test-utils.c"
	}
	_state_0:
#line 48 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	_data_->retval = FALSE;
#line 50 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	_data_->_tmp0_ = _data_->a;
#line 50 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	_data_->_tmp1_ = _data_->b;
#line 50 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	if (_data_->_tmp0_ == _data_->_tmp1_) {
#line 51 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		_data_->result = TRUE;
#line 51 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		if (_data_->_state_ == 0) {
#line 51 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 350 "test-utils.c"
		} else {
#line 51 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 354 "test-utils.c"
		}
#line 51 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		g_object_unref (_data_->_async_result);
#line 51 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		return FALSE;
#line 360 "test-utils.c"
	}
#line 53 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	_data_->_tmp3_ = _data_->a;
#line 53 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	if (_data_->_tmp3_ != NULL) {
#line 53 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		_data_->_tmp4_ = _data_->b;
#line 53 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		_data_->_tmp2_ = _data_->_tmp4_ != NULL;
#line 370 "test-utils.c"
	} else {
#line 53 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		_data_->_tmp2_ = FALSE;
#line 374 "test-utils.c"
	}
#line 53 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	_data_->_tmp5_ = _data_->_tmp2_;
#line 53 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	if (_data_->_tmp5_) {
#line 380 "test-utils.c"
		{
#line 58 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			_data_->_tmp6_ = _data_->a;
#line 58 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			_data_->_tmp7_ = _data_->icon_size;
#line 58 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			_data_->_tmp8_ = NULL;
#line 58 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			_data_->_state_ = 1;
#line 58 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			g_loadable_icon_load_async (_data_->_tmp6_, _data_->_tmp7_, NULL, folks_test_utils_loadable_icons_content_equal_ready, _data_);
#line 58 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			return FALSE;
#line 394 "test-utils.c"
			_state_1:
#line 58 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			_data_->_tmp9_ = NULL;
#line 58 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			_data_->_tmp9_ = g_loadable_icon_load_finish (_data_->_tmp6_, _data_->_res_, &_data_->_tmp8_, &_data_->_inner_error_);
#line 58 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			_g_free0 (_data_->a_type);
#line 58 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			_data_->a_type = _data_->_tmp8_;
#line 58 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			_data_->a_input = _data_->_tmp9_;
#line 58 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			if (_data_->_inner_error_ != NULL) {
#line 58 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
				_g_free0 (_data_->a_type);
#line 410 "test-utils.c"
				goto __catch0_g_error;
			}
#line 60 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			_data_->_tmp10_ = _data_->b;
#line 60 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			_data_->_tmp11_ = _data_->icon_size;
#line 60 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			_data_->_tmp12_ = NULL;
#line 60 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			_data_->_state_ = 2;
#line 60 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			g_loadable_icon_load_async (_data_->_tmp10_, _data_->_tmp11_, NULL, folks_test_utils_loadable_icons_content_equal_ready, _data_);
#line 60 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			return FALSE;
#line 425 "test-utils.c"
			_state_2:
#line 60 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			_data_->_tmp13_ = NULL;
#line 60 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			_data_->_tmp13_ = g_loadable_icon_load_finish (_data_->_tmp10_, _data_->_res_, &_data_->_tmp12_, &_data_->_inner_error_);
#line 60 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			_g_free0 (_data_->b_type);
#line 60 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			_data_->b_type = _data_->_tmp12_;
#line 60 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			_data_->b_input = _data_->_tmp13_;
#line 60 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			if (_data_->_inner_error_ != NULL) {
#line 60 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
				_g_free0 (_data_->b_type);
#line 60 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
				_g_object_unref0 (_data_->a_input);
#line 60 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
				_g_free0 (_data_->a_type);
#line 445 "test-utils.c"
				goto __catch0_g_error;
			}
#line 63 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			_data_->bufsize = (gsize) 2048;
#line 64 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			_data_->_tmp14_ = _data_->bufsize;
#line 64 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			_data_->_tmp15_ = NULL;
#line 64 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			_data_->_tmp15_ = g_new0 (guint8, _data_->_tmp14_);
#line 64 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			_data_->a_data = _data_->_tmp15_;
#line 64 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			_data_->a_data_length1 = _data_->_tmp14_;
#line 64 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			_data_->_a_data_size_ = _data_->a_data_length1;
#line 65 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			_data_->_tmp16_ = _data_->bufsize;
#line 65 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			_data_->_tmp17_ = NULL;
#line 65 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			_data_->_tmp17_ = g_new0 (guint8, _data_->_tmp16_);
#line 65 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			_data_->b_data = _data_->_tmp17_;
#line 65 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			_data_->b_data_length1 = _data_->_tmp16_;
#line 65 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			_data_->_b_data_size_ = _data_->b_data_length1;
#line 68 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			_data_->retval = TRUE;
#line 69 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			_data_->a_read_size = (gsize) (-1);
#line 478 "test-utils.c"
			{
#line 70 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
				_data_->_tmp18_ = TRUE;
#line 70 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
				while (TRUE) {
#line 70 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
					_data_->_tmp19_ = _data_->_tmp18_;
#line 70 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
					if (!_data_->_tmp19_) {
#line 82 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
						_data_->_tmp20_ = _data_->a_read_size;
#line 82 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
						if (!(_data_->_tmp20_ > ((gsize) 0))) {
#line 82 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
							break;
#line 494 "test-utils.c"
						}
					}
#line 70 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
					_data_->_tmp18_ = FALSE;
#line 72 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
					_data_->_tmp21_ = _data_->a_input;
#line 72 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
					_data_->_tmp22_ = _data_->a_data;
#line 72 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
					_data_->_tmp22__length1 = _data_->a_data_length1;
#line 72 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
					_data_->_state_ = 3;
#line 72 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
					g_input_stream_read_async (_data_->_tmp21_, (void*) _data_->_tmp22_, (gsize) _data_->_tmp22__length1, G_PRIORITY_DEFAULT, NULL, folks_test_utils_loadable_icons_content_equal_ready, _data_);
#line 72 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
					return FALSE;
#line 511 "test-utils.c"
					_state_3:
#line 72 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
					_data_->_tmp23_ = 0L;
#line 72 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
					_data_->_tmp23_ = g_input_stream_read_finish (_data_->_tmp21_, _data_->_res_, &_data_->_inner_error_);
#line 72 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
					_data_->_tmp24_ = _data_->_tmp23_;
#line 72 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
					if (_data_->_inner_error_ != NULL) {
#line 72 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
						_data_->b_data = (g_free (_data_->b_data), NULL);
#line 72 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
						_data_->a_data = (g_free (_data_->a_data), NULL);
#line 72 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
						_g_object_unref0 (_data_->b_input);
#line 72 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
						_g_free0 (_data_->b_type);
#line 72 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
						_g_object_unref0 (_data_->a_input);
#line 72 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
						_g_free0 (_data_->a_type);
#line 533 "test-utils.c"
						goto __catch0_g_error;
					}
#line 72 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
					_data_->a_read_size = (gsize) _data_->_tmp24_;
#line 73 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
					_data_->_tmp25_ = _data_->b_input;
#line 73 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
					_data_->_tmp26_ = _data_->b_data;
#line 73 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
					_data_->_tmp26__length1 = _data_->b_data_length1;
#line 73 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
					_data_->_state_ = 4;
#line 73 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
					g_input_stream_read_async (_data_->_tmp25_, (void*) _data_->_tmp26_, (gsize) _data_->_tmp26__length1, G_PRIORITY_DEFAULT, NULL, folks_test_utils_loadable_icons_content_equal_ready, _data_);
#line 73 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
					return FALSE;
#line 550 "test-utils.c"
					_state_4:
#line 73 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
					_data_->_tmp27_ = 0L;
#line 73 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
					_data_->_tmp27_ = g_input_stream_read_finish (_data_->_tmp25_, _data_->_res_, &_data_->_inner_error_);
#line 73 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
					_data_->b_read_size = _data_->_tmp27_;
#line 73 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
					if (_data_->_inner_error_ != NULL) {
#line 73 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
						_data_->b_data = (g_free (_data_->b_data), NULL);
#line 73 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
						_data_->a_data = (g_free (_data_->a_data), NULL);
#line 73 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
						_g_object_unref0 (_data_->b_input);
#line 73 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
						_g_free0 (_data_->b_type);
#line 73 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
						_g_object_unref0 (_data_->a_input);
#line 73 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
						_g_free0 (_data_->a_type);
#line 572 "test-utils.c"
						goto __catch0_g_error;
					}
#line 75 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
					_data_->_tmp29_ = _data_->a_read_size;
#line 75 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
					_data_->_tmp30_ = _data_->b_read_size;
#line 75 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
					if (_data_->_tmp29_ != ((gsize) _data_->_tmp30_)) {
#line 75 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
						_data_->_tmp28_ = TRUE;
#line 583 "test-utils.c"
					} else {
#line 76 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
						_data_->_tmp31_ = _data_->a_data;
#line 76 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
						_data_->_tmp31__length1 = _data_->a_data_length1;
#line 76 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
						_data_->_tmp32_ = _data_->b_data;
#line 76 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
						_data_->_tmp32__length1 = _data_->b_data_length1;
#line 76 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
						_data_->_tmp33_ = _data_->a_read_size;
#line 76 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
						_data_->_tmp34_ = 0;
#line 76 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
						_data_->_tmp34_ = memcmp (_data_->_tmp31_, _data_->_tmp32_, _data_->_tmp33_);
#line 76 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
						_data_->_tmp28_ = _data_->_tmp34_ != 0;
#line 601 "test-utils.c"
					}
#line 75 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
					_data_->_tmp35_ = _data_->_tmp28_;
#line 75 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
					if (_data_->_tmp35_) {
#line 78 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
						_data_->retval = FALSE;
#line 79 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
						break;
#line 611 "test-utils.c"
					}
				}
			}
#line 84 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			_data_->_tmp36_ = _data_->a_input;
#line 84 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			_data_->_state_ = 5;
#line 84 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			g_input_stream_close_async (_data_->_tmp36_, G_PRIORITY_DEFAULT, NULL, folks_test_utils_loadable_icons_content_equal_ready, _data_);
#line 84 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			return FALSE;
#line 623 "test-utils.c"
			_state_5:
#line 84 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			g_input_stream_close_finish (_data_->_tmp36_, _data_->_res_, &_data_->_inner_error_);
#line 84 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			if (_data_->_inner_error_ != NULL) {
#line 84 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
				_data_->b_data = (g_free (_data_->b_data), NULL);
#line 84 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
				_data_->a_data = (g_free (_data_->a_data), NULL);
#line 84 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
				_g_object_unref0 (_data_->b_input);
#line 84 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
				_g_free0 (_data_->b_type);
#line 84 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
				_g_object_unref0 (_data_->a_input);
#line 84 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
				_g_free0 (_data_->a_type);
#line 641 "test-utils.c"
				goto __catch0_g_error;
			}
#line 85 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			_data_->_tmp37_ = _data_->b_input;
#line 85 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			_data_->_state_ = 6;
#line 85 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			g_input_stream_close_async (_data_->_tmp37_, G_PRIORITY_DEFAULT, NULL, folks_test_utils_loadable_icons_content_equal_ready, _data_);
#line 85 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			return FALSE;
#line 652 "test-utils.c"
			_state_6:
#line 85 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			g_input_stream_close_finish (_data_->_tmp37_, _data_->_res_, &_data_->_inner_error_);
#line 85 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			if (_data_->_inner_error_ != NULL) {
#line 85 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
				_data_->b_data = (g_free (_data_->b_data), NULL);
#line 85 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
				_data_->a_data = (g_free (_data_->a_data), NULL);
#line 85 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
				_g_object_unref0 (_data_->b_input);
#line 85 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
				_g_free0 (_data_->b_type);
#line 85 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
				_g_object_unref0 (_data_->a_input);
#line 85 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
				_g_free0 (_data_->a_type);
#line 670 "test-utils.c"
				goto __catch0_g_error;
			}
#line 55 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			_data_->b_data = (g_free (_data_->b_data), NULL);
#line 55 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			_data_->a_data = (g_free (_data_->a_data), NULL);
#line 55 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			_g_object_unref0 (_data_->b_input);
#line 55 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			_g_free0 (_data_->b_type);
#line 55 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			_g_object_unref0 (_data_->a_input);
#line 55 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			_g_free0 (_data_->a_type);
#line 685 "test-utils.c"
		}
		goto __finally0;
		__catch0_g_error:
		{
#line 55 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			_data_->e1 = _data_->_inner_error_;
#line 55 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			_data_->_inner_error_ = NULL;
#line 89 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			_data_->retval = FALSE;
#line 90 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			_data_->_tmp38_ = _data_->e1;
#line 90 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			_data_->_tmp39_ = _data_->_tmp38_->message;
#line 90 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			g_warning ("test-utils.vala:90: Failed to read loadable icon for comparison: %s", _data_->_tmp39_);
#line 55 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			_g_error_free0 (_data_->e1);
#line 704 "test-utils.c"
		}
		__finally0:
#line 55 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		if (_data_->_inner_error_ != NULL) {
#line 55 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 55 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			g_clear_error (&_data_->_inner_error_);
#line 55 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			return FALSE;
#line 715 "test-utils.c"
		}
	}
#line 95 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	_data_->result = _data_->retval;
#line 95 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	if (_data_->_state_ == 0) {
#line 95 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 724 "test-utils.c"
	} else {
#line 95 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 728 "test-utils.c"
	}
#line 95 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	g_object_unref (_data_->_async_result);
#line 95 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	return FALSE;
#line 44 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	if (_data_->_state_ == 0) {
#line 44 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 738 "test-utils.c"
	} else {
#line 44 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 742 "test-utils.c"
	}
#line 44 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	g_object_unref (_data_->_async_result);
#line 44 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	return FALSE;
#line 748 "test-utils.c"
}


static void folks_test_utils_aggregator_prepare_and_wait_for_quiescence_data_free (gpointer _data) {
	FolksTestUtilsAggregatorPrepareAndWaitForQuiescenceData* _data_;
	_data_ = _data;
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	_g_object_unref0 (_data_->aggregator);
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	g_slice_free (FolksTestUtilsAggregatorPrepareAndWaitForQuiescenceData, _data_);
#line 759 "test-utils.c"
}


void folks_test_utils_aggregator_prepare_and_wait_for_quiescence (FolksIndividualAggregator* aggregator, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	FolksTestUtilsAggregatorPrepareAndWaitForQuiescenceData* _data_;
	FolksIndividualAggregator* _tmp0_;
	FolksIndividualAggregator* _tmp1_;
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	_data_ = g_slice_new0 (FolksTestUtilsAggregatorPrepareAndWaitForQuiescenceData);
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	_data_->_async_result = g_simple_async_result_new (NULL, _callback_, _user_data_, folks_test_utils_aggregator_prepare_and_wait_for_quiescence);
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, folks_test_utils_aggregator_prepare_and_wait_for_quiescence_data_free);
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	_tmp0_ = aggregator;
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	_data_->aggregator = _tmp1_;
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	folks_test_utils_aggregator_prepare_and_wait_for_quiescence_co (_data_);
#line 781 "test-utils.c"
}


void folks_test_utils_aggregator_prepare_and_wait_for_quiescence_finish (GAsyncResult* _res_, GError** error) {
	FolksTestUtilsAggregatorPrepareAndWaitForQuiescenceData* _data_;
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		return;
#line 791 "test-utils.c"
	}
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 795 "test-utils.c"
}


/**
   * Prepare an aggregator and wait for it to reach quiescence.
   *
   * This will prepare the given {@link IndividualAggregator} then yield until
   * it reaches quiescence. No timeout is used, so if the aggregator never
   * reaches quiescence, this function will never return; callers must add their
   * own timeout to avoid this if necessary.
   *
   * When this returns, the aggregator is guaranteed to be quiescent.
   *
   * @param aggregator the aggregator to prepare
   */
static Block1Data* block1_data_ref (Block1Data* _data1_) {
#line 110 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	g_atomic_int_inc (&_data1_->_ref_count_);
#line 110 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	return _data1_;
#line 816 "test-utils.c"
}


static void block1_data_unref (void * _userdata_) {
	Block1Data* _data1_;
	_data1_ = (Block1Data*) _userdata_;
#line 110 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	if (g_atomic_int_dec_and_test (&_data1_->_ref_count_)) {
#line 110 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		g_slice_free (Block1Data, _data1_);
#line 827 "test-utils.c"
	}
}


static void __lambda2_ (Block1Data* _data1_, GObject* obj, GParamSpec* pspec) {
	gboolean _tmp0_;
#line 114 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	g_return_if_fail (obj != NULL);
#line 114 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	g_return_if_fail (pspec != NULL);
#line 116 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	_tmp0_ = _data1_->has_yielded;
#line 116 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	if (_tmp0_ == TRUE) {
#line 118 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		folks_test_utils_aggregator_prepare_and_wait_for_quiescence_co (_data1_->_async_data_);
#line 844 "test-utils.c"
	}
}


static void ___lambda2__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 114 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	__lambda2_ (self, _sender, pspec);
#line 852 "test-utils.c"
}


static void folks_test_utils_aggregator_prepare_and_wait_for_quiescence_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	FolksTestUtilsAggregatorPrepareAndWaitForQuiescenceData* _data_;
#line 124 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	_data_ = _user_data_;
#line 124 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	_data_->_source_object_ = source_object;
#line 124 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	_data_->_res_ = _res_;
#line 124 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	folks_test_utils_aggregator_prepare_and_wait_for_quiescence_co (_data_);
#line 866 "test-utils.c"
}


static gboolean folks_test_utils_aggregator_prepare_and_wait_for_quiescence_co (FolksTestUtilsAggregatorPrepareAndWaitForQuiescenceData* _data_) {
#line 110 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	switch (_data_->_state_) {
#line 110 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		case 0:
#line 875 "test-utils.c"
		goto _state_0;
#line 110 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		case 1:
#line 879 "test-utils.c"
		goto _state_1;
#line 110 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		case 2:
#line 883 "test-utils.c"
		goto _state_2;
		default:
#line 110 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		g_assert_not_reached ();
#line 888 "test-utils.c"
	}
	_state_0:
#line 110 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	_data_->_data1_ = g_slice_new0 (Block1Data);
#line 110 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	_data_->_data1_->_ref_count_ = 1;
#line 110 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	_data_->_data1_->_async_data_ = _data_;
#line 113 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	_data_->_data1_->has_yielded = FALSE;
#line 114 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	_data_->_tmp0_ = _data_->aggregator;
#line 114 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	_data_->_tmp1_ = 0UL;
#line 114 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	_data_->_tmp1_ = g_signal_connect_data ((GObject*) _data_->_tmp0_, "notify::is-quiescent", (GCallback) ___lambda2__g_object_notify, block1_data_ref (_data_->_data1_), (GClosureNotify) block1_data_unref, 0);
#line 114 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	_data_->signal_id = _data_->_tmp1_;
#line 907 "test-utils.c"
	{
#line 124 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		_data_->_tmp2_ = _data_->aggregator;
#line 124 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		_data_->_state_ = 1;
#line 124 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		folks_individual_aggregator_prepare (_data_->_tmp2_, folks_test_utils_aggregator_prepare_and_wait_for_quiescence_ready, _data_);
#line 124 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		return FALSE;
#line 917 "test-utils.c"
		_state_1:
#line 124 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		folks_individual_aggregator_prepare_finish (_data_->_tmp2_, _data_->_res_, &_data_->_inner_error_);
#line 124 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		if (_data_->_inner_error_ != NULL) {
#line 923 "test-utils.c"
			goto __finally1;
		}
#line 126 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		_data_->_tmp3_ = _data_->aggregator;
#line 126 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		_data_->_tmp4_ = folks_individual_aggregator_get_is_quiescent (_data_->_tmp3_);
#line 126 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		_data_->_tmp5_ = _data_->_tmp4_;
#line 126 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		if (_data_->_tmp5_ == FALSE) {
#line 128 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			_data_->_data1_->has_yielded = TRUE;
#line 129 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			_data_->_state_ = 2;
#line 129 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			return FALSE;
#line 940 "test-utils.c"
			_state_2:
			;
		}
	}
	__finally1:
	{
#line 134 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		_data_->_tmp6_ = _data_->aggregator;
#line 134 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		_data_->_tmp7_ = _data_->signal_id;
#line 134 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		g_signal_handler_disconnect ((GObject*) _data_->_tmp6_, _data_->_tmp7_);
#line 135 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		_data_->_tmp8_ = _data_->aggregator;
#line 135 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		_data_->_tmp9_ = folks_individual_aggregator_get_is_quiescent (_data_->_tmp8_);
#line 135 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		_data_->_tmp10_ = _data_->_tmp9_;
#line 135 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		_vala_assert (_data_->_tmp10_ == TRUE, "aggregator.is_quiescent == true");
#line 961 "test-utils.c"
	}
#line 122 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	if (_data_->_inner_error_ != NULL) {
#line 122 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 122 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		g_error_free (_data_->_inner_error_);
#line 122 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		block1_data_unref (_data_->_data1_);
#line 122 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		_data_->_data1_ = NULL;
#line 122 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		if (_data_->_state_ == 0) {
#line 122 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 977 "test-utils.c"
		} else {
#line 122 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 981 "test-utils.c"
		}
#line 122 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		g_object_unref (_data_->_async_result);
#line 122 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		return FALSE;
#line 987 "test-utils.c"
	}
#line 110 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	block1_data_unref (_data_->_data1_);
#line 110 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	_data_->_data1_ = NULL;
#line 110 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	if (_data_->_state_ == 0) {
#line 110 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 997 "test-utils.c"
	} else {
#line 110 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1001 "test-utils.c"
	}
#line 110 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	g_object_unref (_data_->_async_result);
#line 110 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	return FALSE;
#line 1007 "test-utils.c"
}


FolksTestUtils* folks_test_utils_construct (GType object_type) {
	FolksTestUtils* self = NULL;
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	self = (FolksTestUtils*) g_type_create_instance (object_type);
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	return self;
#line 1017 "test-utils.c"
}


FolksTestUtils* folks_test_utils_new (void) {
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	return folks_test_utils_construct (FOLKS_TYPE_TEST_UTILS);
#line 1024 "test-utils.c"
}


static void folks_value_test_utils_init (GValue* value) {
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	value->data[0].v_pointer = NULL;
#line 1031 "test-utils.c"
}


static void folks_value_test_utils_free_value (GValue* value) {
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	if (value->data[0].v_pointer) {
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		folks_test_utils_unref (value->data[0].v_pointer);
#line 1040 "test-utils.c"
	}
}


static void folks_value_test_utils_copy_value (const GValue* src_value, GValue* dest_value) {
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	if (src_value->data[0].v_pointer) {
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		dest_value->data[0].v_pointer = folks_test_utils_ref (src_value->data[0].v_pointer);
#line 1050 "test-utils.c"
	} else {
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		dest_value->data[0].v_pointer = NULL;
#line 1054 "test-utils.c"
	}
}


static gpointer folks_value_test_utils_peek_pointer (const GValue* value) {
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	return value->data[0].v_pointer;
#line 1062 "test-utils.c"
}


static gchar* folks_value_test_utils_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	if (collect_values[0].v_pointer) {
#line 1069 "test-utils.c"
		FolksTestUtils* object;
		object = collect_values[0].v_pointer;
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		if (object->parent_instance.g_class == NULL) {
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 1076 "test-utils.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 1080 "test-utils.c"
		}
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		value->data[0].v_pointer = folks_test_utils_ref (object);
#line 1084 "test-utils.c"
	} else {
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		value->data[0].v_pointer = NULL;
#line 1088 "test-utils.c"
	}
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	return NULL;
#line 1092 "test-utils.c"
}


static gchar* folks_value_test_utils_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	FolksTestUtils** object_p;
	object_p = collect_values[0].v_pointer;
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	if (!object_p) {
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 1103 "test-utils.c"
	}
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	if (!value->data[0].v_pointer) {
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		*object_p = NULL;
#line 1109 "test-utils.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		*object_p = value->data[0].v_pointer;
#line 1113 "test-utils.c"
	} else {
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		*object_p = folks_test_utils_ref (value->data[0].v_pointer);
#line 1117 "test-utils.c"
	}
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	return NULL;
#line 1121 "test-utils.c"
}


GParamSpec* folks_param_spec_test_utils (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	FolksParamSpecTestUtils* spec;
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	g_return_val_if_fail (g_type_is_a (object_type, FOLKS_TYPE_TEST_UTILS), NULL);
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	return G_PARAM_SPEC (spec);
#line 1135 "test-utils.c"
}


gpointer folks_value_get_test_utils (const GValue* value) {
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, FOLKS_TYPE_TEST_UTILS), NULL);
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	return value->data[0].v_pointer;
#line 1144 "test-utils.c"
}


void folks_value_set_test_utils (GValue* value, gpointer v_object) {
	FolksTestUtils* old;
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, FOLKS_TYPE_TEST_UTILS));
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	old = value->data[0].v_pointer;
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	if (v_object) {
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, FOLKS_TYPE_TEST_UTILS));
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		value->data[0].v_pointer = v_object;
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		folks_test_utils_ref (value->data[0].v_pointer);
#line 1164 "test-utils.c"
	} else {
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		value->data[0].v_pointer = NULL;
#line 1168 "test-utils.c"
	}
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	if (old) {
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		folks_test_utils_unref (old);
#line 1174 "test-utils.c"
	}
}


void folks_value_take_test_utils (GValue* value, gpointer v_object) {
	FolksTestUtils* old;
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, FOLKS_TYPE_TEST_UTILS));
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	old = value->data[0].v_pointer;
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	if (v_object) {
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, FOLKS_TYPE_TEST_UTILS));
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		value->data[0].v_pointer = v_object;
#line 1193 "test-utils.c"
	} else {
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		value->data[0].v_pointer = NULL;
#line 1197 "test-utils.c"
	}
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	if (old) {
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		folks_test_utils_unref (old);
#line 1203 "test-utils.c"
	}
}


static void folks_test_utils_class_init (FolksTestUtilsClass * klass) {
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	folks_test_utils_parent_class = g_type_class_peek_parent (klass);
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	FOLKS_TEST_UTILS_CLASS (klass)->finalize = folks_test_utils_finalize;
#line 1213 "test-utils.c"
}


static void folks_test_utils_instance_init (FolksTestUtils * self) {
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	self->ref_count = 1;
#line 1220 "test-utils.c"
}


static void folks_test_utils_finalize (FolksTestUtils* obj) {
	FolksTestUtils * self;
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, FOLKS_TYPE_TEST_UTILS, FolksTestUtils);
#line 1228 "test-utils.c"
}


GType folks_test_utils_get_type (void) {
	static volatile gsize folks_test_utils_type_id__volatile = 0;
	if (g_once_init_enter (&folks_test_utils_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { folks_value_test_utils_init, folks_value_test_utils_free_value, folks_value_test_utils_copy_value, folks_value_test_utils_peek_pointer, "p", folks_value_test_utils_collect_value, "p", folks_value_test_utils_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (FolksTestUtilsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) folks_test_utils_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (FolksTestUtils), 0, (GInstanceInitFunc) folks_test_utils_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType folks_test_utils_type_id;
		folks_test_utils_type_id = g_type_register_fundamental (g_type_fundamental_next (), "FolksTestUtils", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&folks_test_utils_type_id__volatile, folks_test_utils_type_id);
	}
	return folks_test_utils_type_id__volatile;
}


gpointer folks_test_utils_ref (gpointer instance) {
	FolksTestUtils* self;
	self = instance;
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	g_atomic_int_inc (&self->ref_count);
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	return instance;
#line 1253 "test-utils.c"
}


void folks_test_utils_unref (gpointer instance) {
	FolksTestUtils* self;
	self = instance;
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		FOLKS_TEST_UTILS_GET_CLASS (self)->finalize (self);
#line 26 "/home/jpwhiting/devel/collabora/src/gnome/folks/tests/lib/test-utils.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 1266 "test-utils.c"
	}
}



